.. module:: wwdtm.panelist

****************
Module: panelist
****************

This module provides objects used to retrieve panelists, panelist information
and panelist details from a copy of the Wait Wait Don't Tell Me! Stats
database.

Panelist
========

.. autoclass:: wwdtm.panelist.Panelist
    :members:
    :inherited-members:

PanelistAppearances
===================

.. autoclass:: wwdtm.panelist.PanelistAppearances
    :members:
    :inherited-members:

PanelistDecimalScores
======================

.. autoclass:: wwdtm.panelist.PanelistDecimalScores
    :members:
    :inherited-members:

PanelistScores
==============

.. autoclass:: wwdtm.panelist.PanelistScores
    :members:
    :inherited-members:

PanelistStatistics
==================

.. autoclass:: wwdtm.panelist.PanelistStatistics
    :members:
    :inherited-members:

PanelistUtility
===============

.. autoclass:: wwdtm.panelist.PanelistUtility
    :members:
    :inherited-members:
